/*
 *   This file is part of the MLV Library.
 *
 *   Copyright (C) 2010 Adrien Boussicault, Marc Zipstein
 *
 *
 *    This Library is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This Library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this Library.  If not, see <http://www.gnu.org/licenses/>.
 */

/** \~french 
 * \file MLV_informations.h
 *
 * \author Adrien Boussicault
 * \author Marc Zipstein
 *
 * \brief Ce fichier définit les prototypes des fonction permettant de récupérer
 *        des informations sur la librairie.
 */

#ifndef __MLV_INFORMATIONS_H__
#define __MLV_INFORMATIONS_H__

#ifdef __cplusplus
extern "C" {
#endif

/** \~french 
 * \brief Renvoie le nom de la librairie.
 *
 * \return Nom de la librairie
 */
const char* MLV_get_package_name( );

/** \~french 
 * \brief Renvoie la version de la librairie
 *
 * \return Version de la librairie
 */
const char* MLV_get_version( );

/** \~french 
 * \brief Renvoie l'addresse mail à laquelle vous pouvez envoyer les bugs que 
 *        vous rencontrez.
 *
 * \return Addresse mail
 */
const char* MLV_get_bug_report_address( );

/** \~french 
 * \brief Renvoie la licence de la librairie.
 *
 * \return La licence de la librairie
 */
const char* MLV_get_licence( );

/** \~french 
 * \brief Renvoie l'addresse internet où l'on peut trouver les code source de la
 *        librairie.
 *
 * \return L'addresse internet où l'on peut trouver le code source de la
 *         librairie.
 */
const char* MLV_get_web_distribution( );

#ifdef __cplusplus
}
#endif

#endif

