/**
 * Ce programme explique commen utilise l'interface simplifié de la librairie
 * pour lire et recupere des informations contenu dans des fichiers écrits au
 * format xml.
 *
 * -----------------------------------------------------------------------------
 * MLV_load_xml: Charge en mémoire un fichier au format xml.
 *
 * Cette fonction renvoi NULL, lorsque le fichier n'a pas pu être correctement
 * chargé.
 *
 * Cette fonction renvoie le fichier xml lu, anamlysé et chargé.
 *
 * MLV_Xml* MLV_load_xml(
 *     const char*     xml_file_path     Chemin d'accès du fichier xml.
 * );
 *
 * -----------------------------------------------------------------------------
 * MLV_get_string_value_from_xml: Permet d'accedr à l'interieur d'un champs
 *                                donne du fichier xml.
 *
 * Cette fonction renvoie la chaine de caracter du champs recuperé à l'interieur
 * du fichier xml.
 *
 * char* MLV_get_string_value_from_xml(
 *     MLV_Xml*        xml_data,     les données xml.
 *     int             i,            le ieme champs apparaissant dans le fichier
 *                                   et vérifiant le xpath
 *     const char*     xpath,        Le chemin d'acces codé en xpath.
 *     ...                           les parametres de la fonction.
 * );
 *
 * -----------------------------------------------------------------------------
 * MLV_get_integer_value_from_xml: Permet de recupere l'entier d'un champs donne
 *                                 du fichier xml.
 *
 * Cette fonction renvoie l'entier encode par le champs du fichier.
 *
 * int MLV_get_integer_value_from_xml(
 *     MLV_Xml*        xml_data,    les données xml.
 *     int             i,           le ieme champs apparaissant dans le fichier
 *                                  et vérifiant le xpath
 *     const char*     xpath,       Le chemin d'accesles parametres de la fonction.
 *     ...
 * );
 *
 * -----------------------------------------------------------------------------
 * MLV_get_double_value_from_xml: Permet de recupere le reel d'un champs donne
 *                                du fichier xml.
 *
 * Cette fonction renvoie le reel (double) encode par le champs du fichier.
 *
 * double MLV_get_double_value_from_xml(
 *     MLV_Xml*        xml_data,     les données xml.
 *     int             i,            le ieme champs apparaissant dans le fichier
 *                                   et vérifiant le xpath
 *     const char*     xpath,        Le chemin d'accesles parametres de la
 *                                   fonction.
 *     ...
 * );
 *
 * -----------------------------------------------------------------------------
 * MLV_free_xml: Libère la mémoire utilisée par les donnees du fichier xml.
 *
 * void MLV_free_xml(
 *     MLV_Xml*     xml_data     les données xml a supprimer.
 * );
 *
 * -----------------------------------------------------------------------------
 *
 *
 */

#include  <MLV/MLV_all.h>
#include  <stdlib.h>

//
// Attention ! 
// Pour pouvoir compiler ce programme sous windows et sous macintosh,
// il faut, pour la déclaration du main, respecter strictement la syntaxe
// suivante :
//
int main( int argc, char *argv[] ){

	int annee;
	MLV_Xml* config;
	char* text;
	double reel;
	
	//
	// On charge en mémoire le fichier XMl contenant toutes les informations
	// nécessaire au fonctionnement du programme.
	//	
	config = MLV_load_xml( "informations.xml" );


	//
	// On récupere, puis on affiche le texte contenu dans l'élément 
	// informations/non_programme
	//
	text = MLV_get_string_value_from_xml(
		config, 0, "/informations/nom_programme"
	);
	if( !text ){
		printf( "Le fichier XML est corrompu, l'élément /informations/nom_programme est manquant.\n" );
		exit(1);
	}

	printf("Titre : %s\n", text);
	free(text);

	
	//
	// On récupere, puis on affiche l'entier contenu dans l'élément 
	// informations/anne_production
	//
	annee = MLV_get_integer_value_from_xml(
		config, 0, "/informations/annee_production"
	);

	printf("Annee de production : %d \n", annee);

	
	//
	// On récupere, puis on affiche le reel contenu dans l'élément 
	// informations/reel_prefere
	//
	reel = MLV_get_double_value_from_xml(
		config, 0, "/informations/reel_prefere"
	);

	printf("Mon réel préféré : %f \n", reel);

	//
	// On libere l'espace alloué pour le fichier xml.
	//
	MLV_free_xml( config );

	return 0;
}
